@@ -86,6 +86,7 @@ CREATE TABLE `goip` (
   `fwd_mail_enable` tinyint(1) NOT NULL default '0',
   `report_http` varchar(64) NOT NULL,
   `fwd_http_enable` tinyint(1) NOT NULL default '0',
+  `carrier` varchar(32) NOT NULL,
   PRIMARY KEY  (`id`),
   UNIQUE KEY `name` (`name`),
   KEY `password` (`password`),
@@ -208,6 +209,9 @@ CREATE TABLE `prov` (
   `inter` varchar(10) character set ascii default NULL,
   `local` varchar(10) character set ascii default NULL,
   `recharge_ok_r` varchar(64) NOT NULL,
+  `auto_num_ussd` varchar(20) NOT NULL,
+  `num_prefix` varchar(20) NOT NULL,
+  `num_postfix` varchar(20) NOT NULL,
   PRIMARY KEY  (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
@@ -218,7 +222,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `prov` WRITE;
 /*!40000 ALTER TABLE `prov` DISABLE KEYS */;
-INSERT INTO `prov` VALUES (1,'test','','',''),(2,'','','',''),(3,'','','',''),(4,'','','',''),(5,'','','',''),(6,'','','',''),(7,'','','',''),(8,'','','',''),(9,'','','',''),(10,'','','','');
+INSERT INTO `prov` VALUES (1,'test','','','','','',''),(2,'','','','','','',''),(3,'','','','','','',''),(4,'','','','','','',''),(5,'','','','','','',''),(6,'','','','','','',''),(7,'','','','','','',''),(8,'','','','','','',''),(9,'','','','','','',''),(10,'','','','','','','');
 /*!40000 ALTER TABLE `prov` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -421,7 +425,8 @@ CREATE TABLE `system` (
   `this_day` int(11) NOT NULL default '0',
   `email_forward_sms_enable` tinyint(1) NOT NULL default '0',
   `email_remain_count_enable` tinyint(1) NOT NULL default '0',
-  `email_remain_count_d_enable` tinyint(1) NOT NULL default '0'
+  `email_remain_count_d_enable` tinyint(1) NOT NULL default '0',
+  `session_time` int(11) NOT NULL default '24'
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
 
@@ -431,7 +436,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `system` WRITE;
 /*!40000 ALTER TABLE `system` DISABLE KEYS */;
-INSERT INTO `system` VALUES (70,'goipsms',3,118,'','','','',25,0,5,0,5,'',0,1,0,3,0,0,0,0,0);
+INSERT INTO `system` VALUES (70,'goipsms',3,118,'','','','',25,0,5,0,5,'',0,1,0,3,0,0,0,0,0,24);
 
 /*!40000 ALTER TABLE `system` ENABLE KEYS */;
 UNLOCK TABLES;
@@ -585,10 +590,13 @@ CREATE TABLE IF NOT EXISTS `auto_ussd` (
   `recharge_sms_ok_num` varchar(32) character set utf8 NOT NULL,
   `auto_ussd_step2` varchar(160) character set utf8 NOT NULL,
   `auto_ussd_step2_start_r` varchar(160) character set utf8 NOT NULL,
+  `sms_report_goip` int(11) NOT NULL,
+  `bal_delay` int(11) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `prov_id` (`prov_id`,`goip_id`),
   KEY `recharge_ussd1_goip` (`recharge_ussd1_goip`),
-  KEY `group_id` (`group_id`)
+  KEY `group_id` (`group_id`),
+  KEY `sms_report_goip` (`sms_report_goip`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=latin1;
 
 DROP TABLE IF EXISTS `recharge_card`;
