@@ -319,5 +319,18 @@
 	@$db->updatequery("ALTER TABLE `goip` ADD `fwd_http_enable` BOOL NOT NULL DEFAULT '0'");
 
 	@$db->updatequery("ALTER TABLE `prov` ADD `recharge_ok_r` varchar(64) NOT NULL");
+
+/*1.19.1*/
+	@$db->updatequery("ALTER TABLE `goip` ADD `carrier` varchar(32) NOT NULL");
+
+/*1.19.2*/
+	@$db->updatequery("ALTER TABLE `prov` ADD `auto_num_ussd` varchar(20) NOT NULL");
+	@$db->updatequery("ALTER TABLE `prov` ADD `num_prefix` varchar(20) NOT NULL");
+	@$db->updatequery("ALTER TABLE `prov` ADD `num_postfix` varchar(20) NOT NULL");
+/*1.19.4*/
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `sms_report_goip` int(11) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `bal_delay` int(11) NOT NULL default '0'");
+	@$db->updatequery("ALTER TABLE  `system` ADD `session_time` int(11) NOT NULL default '24'");
+	
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
